<?php
/*
Plugin Name: Neat Skype Status (AJAX and Custom Images)
Plugin URI: http://mission.lt/google-calendar-weekly-timetable-wordpress-plugin/donate
Description: Light and simple plugin displays Skype Button (with Official or Custom Images) in post/page/widget or floating. Status updates without page reload.
Version: 1.1.0
Author: Aurimas Kubeldzis
Author URI: http://mission.lt/google-calendar-weekly-timetable-wordpress-plugin/donate
License: GPL2

---

Copyright 2010 Aurimas Kubeldzis (email: 4urimas@gmail.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

define('SCI_PLUGIN_NAME', str_replace('.php', '', basename(__FILE__)));
define('SCI_TEXT_DOMAIN', 'neat-skype-status');
//define('SCI_OPTIONS_NAME', 'sci_options');
define('SCI_GENERAL_OPTIONS_NAME', 'sci_general' );

if(!class_exists('skype_ajax')){
	class skype_ajax{
		function __construct() {
			register_activation_hook( __FILE__, array( $this, 'activate_plugin' ) );
			//add_action( 'init', array( $this, 'init_plugin' ) );
			add_action( 'wp_ajax_sci_ajax', array( $this, 'sci_ajax' ) );
			add_action( 'wp_ajax_nopriv_sci_ajax', array( $this, 'sci_ajax' ) );
			add_action( 'widgets_init', array( $this, 'add_widget' ) );
			
			//No point doing any of this if currently processing an AJAX request
			if ( ! defined( 'DOING_AJAX' ) || !DOING_AJAX ) {
			add_action( 'admin_menu', array( $this, 'setup_admin' ) );
			add_action( 'wp_footer', array( $this, 'add_to_footer' ) );
			add_action( 'admin_init', array( $this, 'init_admin' ) );
			add_action( 'wp_print_styles', array( $this, 'add_styles' ) );
			add_action( 'wp_print_scripts', array( $this, 'add_scripts' ) );
			add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this, 'add_settings_link' ) );
			add_shortcode( 'skype', array( $this, 'shortcode_handler' ) );
			}
		}
		
		function activate_plugin(){
			if( version_compare( PHP_VERSION, '5.2', '<' ) ) {
				if( is_admin() ) {
					require_once ABSPATH . '/wp-admin/includes/plugin.php';
					deactivate_plugins( basename( __FILE__ ) );
					wp_die( 'This plugin requires the server on which your site resides to be running PHP 5.2 or higher. As of version 3.2, WordPress itself will also <a href="http://wordpress.org/news/2010/07/eol-for-php4-and-mysql4">have this requirement</a>. You should get in touch with your web hosting provider and ask them to update PHP.<br /><br /><a href="' . admin_url( 'plugins.php' ) . '">Back to Plugins</a>' );
				}
			}
		}
		
		//Register the widget
		function add_widget() {
			require_once 'widget/sci-widget.php';
			return register_widget( 'SCI_Widget' );
		}
		
		function init_plugin() {
			//Load text domain for i18n
			//load_plugin_textdomain( SCI_TEXT_DOMAIN, false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );
		}

		//Adds 'Settings' link to main WordPress Plugins page
		function add_settings_link( $links ) {
			array_unshift( $links, '<a href="options-general.php?page=neat-skype-status.php">' . __( 'Settings', SCI_TEXT_DOMAIN ) . '</a>' );
			return $links;
		}
		
		function setup_admin(){
			global $sci_settings_page;

			$sci_settings_page = add_options_page( 'Neat Skype Status', 'Neat Skype Status', 'manage_options', basename( __FILE__ ), array( $this, 'admin_page' ) );

		}
		
		function init_admin() {

			//register_setting( 'sci_options', 'sci_options', array( $this, 'validate_feed_options' ) );
			add_option( SCI_GENERAL_OPTIONS_NAME );
			register_setting( 'sci_general', 'sci_general', array( $this, 'validate_general_options' ) );

		}
		
		function validate_general_options( $input ) {
			$options = get_option(SCI_GENERAL_OPTIONS_NAME);
			
			$options['skype_footer'] = ( isset( $input['skype_footer'] ) ) ? true : false;
			$options['skypename'] = esc_html( $input['skypename'] );
			$options['theme'] = esc_html($input['theme']);
			$interval_value = intval($input['interval']);
			$options['interval'] = (!empty($interval_value))?$interval_value:10000;
			$options['action'] = esc_html($input['action']);
			$options['initial_status'] = esc_html($input['initial_status']);
			$options['initial_check'] = ( isset( $input['initial_check'] ) ) ? true : false;
			$options['preload_images'] = ( isset( $input['preload_images'] ) ) ? true : false;
			
			
			//echo "<pre>$options</pre>";

			add_settings_error( 'sci_general', 'sci_general_updated', __( 'General options updated.', SCI_TEXT_DOMAIN ), 'updated' );

			return $options;
		}
		
		function admin_page() {
			?>
			<div class="wrap">
				<form method="post" action="options.php" id="some-form1">
					<?php
					settings_fields( 'sci_general' );
					//Get saved general options
					$options = get_option(SCI_GENERAL_OPTIONS_NAME);
					/*
					$plugin_dir_name = WP_PLUGIN_URL.'/'.str_replace(basename( __FILE__),"",plugin_basename(__FILE__));
					$some_array = explode('//', $plugin_dir_name );
					$plugin_dir = $some_array[1];
					*/
					?>

					<br />
					<h3><?php _e('Options', SCI_TEXT_DOMAIN); ?></h3>
					
					<table class="form-table">
					
						<tr>
							<th scope="row"><?php _e('Skype name:', SCI_TEXT_DOMAIN); ?></th>
							<td>
								<span class="description"><?php _e('Your skype name that this plugin will be associated with', SCI_TEXT_DOMAIN); ?></span>
								<br />
								<input type="text" name="sci_general[skypename]" value="<?php echo $options['skypename']; ?>" />
							</td>
						</tr>
						
						<tr>
							<th scope="row"><?php _e('Click action', SCI_TEXT_DOMAIN); ?></th>
							<td>
								<span class="description"><?php _e('What do you want skype to do when user clicks on the icon?', SCI_TEXT_DOMAIN); ?></span>
								<br />
								<select name="sci_general[action]">
									<option <?php selected($options['action'], 'call'); ?> value='call'>Call</option>
									<option <?php selected($options['action'], 'chat'); ?> value='chat'>Chat</option>
									<option <?php selected($options['action'], 'add'); ?> value='add'>Add me to skype</option>
									<option <?php selected($options['action'], 'userinfo'); ?> value='userinfo'>View my profile</option>
									<option <?php selected($options['action'], 'voicemail'); ?> value='voicemail'>Leave me voicemail</option>
									<option <?php selected($options['action'], 'sendfile'); ?> value='sendfile'>Send me a file</option>
								</select>
							</td>
						</tr>
						
						<tr>
							<th scope="row"><?php _e('Theme', SCI_TEXT_DOMAIN); ?></th>
							<td>
								<span class="description"><?php _e('If you want to install new ones - make new directory in /images folder and put all the .png images named from 0 to 7 (according to status)', SCI_TEXT_DOMAIN); ?></span>
								<br />
								<select name="sci_general[theme]">
								<?php
									$files = scandir('../wp-content/plugins/neat-skype-status/images/');
									//Print_r($files);
									foreach ($files as $num => $dir_name){
										if ($num > 1){
											$add = ($options['theme'] == $dir_name)?'selected':'';
											echo "<option $add value='$dir_name'>$dir_name</option>";
										}
									}
									
								?>
								</select>
							</td>
						</tr>
						
						<tr>
							<th scope="row"><?php _e('Add floating skype button', SCI_TEXT_DOMAIN); ?></th>
							<td>
								<span class="description"><?php _e('If enabled - you don\'t have to do anything more, if disabled - you have to insert skype status with shortcode / widget', SCI_TEXT_DOMAIN); ?></span>
								<br />
								<input type="checkbox" name="sci_general[skype_footer]"<?php checked($options['skype_footer'], true); ?> value="on" />
							</td>
						</tr>
						
						<tr>
							<th scope="row"><?php _e('Initial check', SCI_TEXT_DOMAIN); ?></th>
							<td>
								<span class="description"><?php _e('If checked - will check skype status while loading page. This can slow down the page, but the status will be loaded the way it is from start.', SCI_TEXT_DOMAIN); ?></span>
								<br />
								<input onclick="javascript: jQuery('#select_initial_status').toggle();" id="initial_check" type="checkbox" name="sci_general[initial_check]"<?php checked($options['initial_check'], true); ?> value="off" />
							</td>
						</tr>
						
						<tr id="select_initial_status">
							<th scope="row"><?php _e('Initial button image', SCI_TEXT_DOMAIN); ?></th>
							<td>
								<span class="description"><?php _e('If you chose not to check status while loading (initial check). What status you want to display while it\'s unknown?', SCI_TEXT_DOMAIN); ?></span>
								<br />
								<select  name="sci_general[initial_status]">
									<option <?php selected($options['initial_status'], '0'); ?> value='0'>Unknown</option>
									<option <?php selected($options['initial_status'], '1'); ?> value='1'>Offline</option>
									<option <?php selected($options['initial_status'], '2'); ?> value='2'>Online</option>
									<option <?php selected($options['initial_status'], '3'); ?> value='3'>Away</option>
									<option <?php selected($options['initial_status'], '4'); ?> value='4'>Not available</option>
									<option <?php selected($options['initial_status'], '5'); ?> value='5'>Do not disturb</option>
									<option <?php selected($options['initial_status'], '6'); ?> value='6'>Invisible</option>
									<option <?php selected($options['initial_status'], '7'); ?> value='7'>Skype me</option>
								</select>
							</td>
						</tr>
						
						<tr>
							<th scope="row"><?php _e('Preload images', SCI_TEXT_DOMAIN); ?></th>
							<td>
								<span class="description"><?php _e('Will load invisible chosen theme images to avoid short flicker when status changes first time (because of image loading)', SCI_TEXT_DOMAIN); ?></span>
								<br />
								<input type="checkbox" name="sci_general[preload_images]"<?php checked($options['preload_images'], true); ?> value="on" />
							</td>
						</tr>
						
						<tr>
							<th scope="row"><?php _e('Update Interval', SCI_TEXT_DOMAIN); ?></th>
							<td>
								<span class="description"><?php _e('Time in miliseconds between AJAX requests to upate status', SCI_TEXT_DOMAIN); ?></span>
								<br />
								<input type="text" name="sci_general[interval]" value="<?php echo $options['interval']; ?>" />
							</td>
						</tr>
						
						
					</table>
					
					<input type="submit" class="button-primary" value="<?php _e('Save', SCI_TEXT_DOMAIN); ?>" />
				</form>
			</div>
			<?php
			
		}
		
		
		
		//Adds the required CSS
		function add_styles() {
			//Don't add styles if on admin screens
			if( ! is_admin() ) {
				
				wp_enqueue_style( 'sci_styles', WP_PLUGIN_URL . '/' . SCI_PLUGIN_NAME . '/css/sci-style.css' );
			}
		}

		//Adds the required scripts
		function add_scripts() {
			//Don't add scripts if on admin pages
			if ( ! is_admin() ) {
				$options = get_option( SCI_GENERAL_OPTIONS_NAME );
				wp_enqueue_script( 'jquery' );
				wp_enqueue_script( 'sci_scripts', WP_PLUGIN_URL . '/' . SCI_PLUGIN_NAME . '/js/sci-script.js', array( 'jquery' ), null, false );
				
				$options = get_option( SCI_GENERAL_OPTIONS_NAME );
				extract($options);
				
				wp_localize_script( 'sci_scripts', 'SkypeCustomImages', array(
					'ajaxurl' => admin_url( 'admin-ajax.php' ),
					'skypename' => $skypename,
					'interval' => $interval
				) );
			}
		}
		
		function sci_ajax() {
			$skypename = $_GET['skypename'];
			//$status = getSkypeStatus($skypename);
			//echo "<br>$skypename<br>labassssssssssssssssssssssssssssssssssssssssss<br><br>";
			//echo $status;
			$icon = getSkypeStatusIcon($skypename);
			echo $icon;
			die();
		}
		
		//Add to footer
		function add_to_footer(){
			$options = get_option( SCI_GENERAL_OPTIONS_NAME );
			extract($options);
			
			if ($preload_images){
				$path = WP_PLUGIN_URL.'/'.str_replace(basename( __FILE__),"",plugin_basename(__FILE__)).'images/'.$theme.'/';
				for ($i=0;$i<8;$i++){
					echo '<img style="display:none" src="'.$path.strval($i).'.png"/>';
				}
			}
			
			if($skype_footer){
			
				if (!empty($skypename)) {
					$image_icon_html = getSkypeStatusIcon($skypename, $initial_check);
					echo '<a class="sk_footer" href="skype:'.$skypename.'?'.$action.'">'.$image_icon_html.' </a>';
				} else {
					echo __( 'You should include skype name in "Neat Skype Status" settings.', SCI_TEXT_DOMAIN );
				} 
			
			}
			
		}
		
		//Handles the shortcode stuff
		function shortcode_handler( $atts ) {
			$options = get_option( SCI_GENERAL_OPTIONS_NAME );
			extract($options);
			//echo "<pre>"; Print_r($options);echo "</pre>";
			
			/*
			extract( shortcode_atts( array(
					'skypename' => '',
			), $atts ), EXTR_OVERWRITE );
			
			if (empty($skypename)) $skypename = $options['skypename'];
			*/

			//Check that skype name was provided
			if (!empty($skypename)) {
				$image_icon_html = getSkypeStatusIcon($skypename, $initial_check);
				return '<a class="sk_shortcode" href="skype:'.$skypename.'?'.$action.'">'.$image_icon_html.' </a>';
			} else {
				return __( 'You should include skype name in "Neat Skype Status" settings.', SCI_TEXT_DOMAIN );
			} 
		}
	
	
	}
}


function getSkypeStatus($username) {
	/*
	returns:
	0 - unknown
	1 - offline
	2 - online
	3 - away
	4 - not available
	5 - do not disturb
	6 - invisible
	7 - skype me
	*/

	/*
	$ch = curl_init();
	curl_setopt($ch, CURLOPT_URL, 'http://mystatus.skype.com/'.$username.'.num');
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
	//curl_setopt($ch, CURLOPT_CONNECTTIMEOUT_MS, 500);
	//curl_setopt($ch, CURLOPT_TIMEOUT_MS, 500);

	$output = curl_exec($ch);
	curl_close($ch);
	echo "skypestatus:$output";
	return $output;
	*/
	// Turn off warnings cause it keeps bothering
	error_reporting(E_ALL ^ E_WARNING);

	$remote_status = fopen ('http://mystatus.skype.com/'.$username.'.num', 'r');
	if (!$remote_status) {
		return '0';
		exit;
	}
	while (!feof ($remote_status)) {
		$value = fgets ($remote_status, 1024);
		return trim($value);
	}
	fclose($remote_status);

}



function getSkypeStatusIcon($username, $http_request = true) {
	$options = get_option( SCI_GENERAL_OPTIONS_NAME );
	extract($options);
	
	if ($http_request) $status = getSkypeStatus($username);
		else $status = $initial_status;
	
	$plugin_dir_name = WP_PLUGIN_URL.'/'.str_replace(basename( __FILE__),"",plugin_basename(__FILE__));

	return '<img src="'.$plugin_dir_name.'images/'.$theme.'/'.$status.'.png" alt="'.$action.' '.$username.'" style="border: none;" />';
}


$gce = new skype_ajax();

?>